0.2.0
Released on October 20, 2022.

- Add optional max-delay-request param to search command.

0.1.0
Released on October 15, 2022.

- Add search command
- Add token config command
- Add gitlab address command
